//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nl/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nl/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nl/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nl/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "nl");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_7-0000000/l10n/nl/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Cliënten,Concurrentie,Diversen,Favorieten,Giften,Ideeën,Klant,Kwesties,Leveranciers,Nationale feestdag,Persoonlijk,Projecten,Reizen,Status,Telefoongesprekken,Trouwdag,Vakantie,Vergadering,Verjaardag,Vervolggesprek,Vrije dagen,Zaken");
